.. pymuvr documentation master file, created by
   sphinx-quickstart on Sat May 24 14:29:53 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pymuvr - fast multi-unit Van Rossum spike train metric
======================================================

:Author: Eugenio Piasini
:Contact: e.piasini@ucl.ac.uk
:Source code: https://github.com/epiasini/pymuvr

.. _introduction:

Multi-unit Van Rossum spike train metric. This is a kernel-based
implementation with markage vector and precomputed exponential factor,
as described in Houghton and Kreuz, 2012, *On the efficient
calculation of Van Rossum distances*. This package started out as a
Python wrapping of the original C++ implementation given by the
authors of the paper, and evolved from there with bugfixes and
improvements.

Contents
========

.. toctree::
   :maxdepth: 2
      
   installation
   usage
   api
   license

